@@ -37,7 +37,7 @@ namespace
       const Handle(IMeshData::MapOfReal)&       theParamsForbiddenToRemove,
       const Handle(IMeshData::MapOfReal)&       theControlParamsForbiddenToRemove)
       : myDFace(theDFace),
-        mySurface(myDFace->GetSurface()->ChangeSurface().Surface().Surface()),
+        mySurface(myDFace->GetSurface()->Surface().Surface()),
         myIsoU(theIsoType == GeomAbs_IsoU),
         myParams(theParams),
         myControlParams(theControlParams),
@@ -333,8 +333,8 @@ Handle(IMeshData::ListOfPnt2d) BRepMesh_NURBSRangeSplitter::GenerateSurfaceNodes
   const std::pair<Standard_Real, Standard_Real>& aDelta  = GetDelta ();
 
   const Standard_Real                 aDefFace = GetDFace()->GetDeflection();
-  const Handle(BRepAdaptor_HSurface)& gFace    = GetSurface();
-  Handle(Geom_Surface)                aSurface = gFace->ChangeSurface().Surface().Surface();
+  const Handle(BRepAdaptor_Surface)& gFace    = GetSurface();
+  Handle(Geom_Surface)                aSurface = gFace->Surface().Surface();
 
   const Handle(NCollection_IncAllocator) aTmpAlloc =
     new NCollection_IncAllocator(IMeshData::MEMORY_BLOCK_SIZE_HUGE);
@@ -398,7 +398,7 @@ Handle(IMeshData::ListOfPnt2d) BRepMesh_NURBSRangeSplitter::GenerateSurfaceNodes
 //=======================================================================
 Standard_Boolean BRepMesh_NURBSRangeSplitter::initParameters() const
 {
-  const Handle(BRepAdaptor_HSurface)& aSurface = GetSurface();
+  const Handle(BRepAdaptor_Surface)& aSurface = GetSurface();
 
   const GeomAbs_Shape aContinuity = GeomAbs_CN;
   const std::pair<Standard_Integer, Standard_Integer> aIntervalsNb(
@@ -414,8 +414,7 @@ Standard_Boolean BRepMesh_NURBSRangeSplitter::initParameters() const
   aSurface->UIntervals(aIntervals[0], aContinuity);
   aSurface->VIntervals(aIntervals[1], aContinuity);
 
-  const Standard_Boolean isSplitIntervals = toSplitIntervals (
-    aSurface->ChangeSurface().Surface().Surface(), aIntervals);
+  const Standard_Boolean isSplitIntervals = toSplitIntervals (aSurface->Surface().Surface(), aIntervals);
 
   if (!initParamsFromIntervals(aIntervals[0], GetRangeU(), isSplitIntervals,
                                const_cast<IMeshData::IMapOfReal&>(GetParametersU())))
