@@ -15,7 +15,7 @@
 // commercial license or contractual agreement.
 
 
-#include <Adaptor3d_HSurface.hxx>
+#include <Adaptor3d_Surface.hxx>
 #include <Bnd_Array1OfBox.hxx>
 #include <Bnd_Box.hxx>
 #include <gp_Pnt.hxx>
@@ -37,7 +37,7 @@
 #define NBMAXUV                     30
 
 //================================================================================
-static Standard_Integer NbPOnU (const Handle(Adaptor3d_HSurface)& S)
+static Standard_Integer NbPOnU (const Handle(Adaptor3d_Surface)& S)
 {
   const Standard_Real u0 = S->FirstUParameter();
   const Standard_Real u1 = S->LastUParameter();
@@ -45,7 +45,7 @@ static Standard_Integer NbPOnU (const Handle(Adaptor3d_HSurface)& S)
   return (nbpu>NBMAXUV? NBMAXUV : nbpu);
 }
 //================================================================================
-static Standard_Integer NbPOnV (const Handle(Adaptor3d_HSurface)& S)
+static Standard_Integer NbPOnV (const Handle(Adaptor3d_Surface)& S)
 {
   const Standard_Real v0 = S->FirstVParameter();
   const Standard_Real v1 = S->LastVParameter();
@@ -69,7 +69,7 @@ void IntPatch_Polyhedron::Destroy()
 //function : IntPatch_Polyhedron
 //purpose  : 
 //=======================================================================
-IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surface)
+IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_Surface)& Surface)
      : TheDeflection(Epsilon(100.)),
        nbdeltaU(NbPOnU(Surface)),
        nbdeltaV(NbPOnV(Surface)),
@@ -126,7 +126,7 @@ IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surf
 //function : IntPatch_Polyhedron
 //purpose  : 
 //=======================================================================
-IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surface,
+IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_Surface)& Surface,
                                           const Standard_Integer nbu,
                                           const Standard_Integer nbv)
 : TheDeflection(Epsilon(100.)),
@@ -188,7 +188,7 @@ IntPatch_Polyhedron::IntPatch_Polyhedron (const Handle(Adaptor3d_HSurface)& Surf
 //=======================================================================
 
 Standard_Real IntPatch_Polyhedron::DeflectionOnTriangle
-  (const Handle(Adaptor3d_HSurface)& Surface,
+  (const Handle(Adaptor3d_Surface)& Surface,
    const Standard_Integer Triang) const 
 {
   Standard_Integer i1,i2,i3;    
